@@ -19,7 +19,7 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 /*
-  $Id: ruli_addr.c,v 1.12 2004/06/16 23:05:58 evertonm Exp $
+  $Id: ruli_addr.c,v 1.13 2004/08/25 19:04:23 evertonm Exp $
   */
 
 
@@ -28,7 +28,7 @@ Boston, MA 02111-1307, USA.
 #endif
 
 
-#include <stdio.h>  /* FIXME: debug */
+#include <stdio.h>
 
 #include <assert.h>
 #include <stdlib.h>
@@ -44,13 +44,6 @@ Boston, MA 02111-1307, USA.
 #include <ruli_mem.h>
 
 
-#ifdef _RULI_SOLARIS_
-#include <limits.h>
-/* gcc 3.3.2 on Solaris 9 was missing this decl */
-extern int snprintf(char *str, size_t size, const char *format, ...);
-#endif
-
-
 ruli_addr_t *ruli_addr_inet_new(struct in_addr ia)
 {
   ruli_addr_t *addr = (ruli_addr_t *) ruli_malloc(sizeof(*addr));
