@@ -16,18 +16,10 @@
  */
 
 /*
-  $Id: ruli_getaddrinfo.c,v 1.9 2004/06/16 21:53:30 evertonm Exp $
+  $Id: ruli_getaddrinfo.c,v 1.11 2004/08/25 19:04:23 evertonm Exp $
 */
 
 
-#include <assert.h>
-#include <stdlib.h>
-#include <string.h>
-#include <netinet/in.h>
-#include <sys/types.h>
-#include <sys/socket.h>
-#include <errno.h>
-
 #ifndef __USE_GNU
 #define __USE_GNU
 #endif
@@ -40,8 +32,15 @@
 #define __USE_POSIX
 #endif
 
+#include <assert.h>
+#include <stdlib.h>
+#include <netinet/in.h>
+#include <sys/types.h>
+#include <sys/socket.h>
+#include <errno.h>
 #include <netdb.h>
 #include <stdio.h>
+#include <string.h>
 #include <dlfcn.h>
 
 #include <ruli_getaddrinfo.h>
@@ -58,14 +57,12 @@ typedef struct {
   } sa;
 } _ruli_ai_addrbag;
 
-
-/* should be in <stdio.h> */
-extern int snprintf(char *str, size_t size, const char *format, ...);
+typedef int (*getaddrinfo_call)(const char *node, const char *service,
+	const struct addrinfo *hints,
+	struct addrinfo **res);
 
 
-static int (*real_getaddrinfo)(const char *node, const char *service,
-			       const struct addrinfo *hints,
-			       struct addrinfo **res) = NULL;
+getaddrinfo_call real_getaddrinfo = NULL;
 
 
 static int call_getaddrinfo(const char *node, const char *service,
@@ -73,11 +70,7 @@ static int call_getaddrinfo(const char *node, const char *service,
 			    struct addrinfo **_res)
 {
   if (!real_getaddrinfo)
-    real_getaddrinfo = (int (*)(const char *,
-				const char *,
-				const struct addrinfo *,
-				struct addrinfo **))
-      dlsym(RTLD_NEXT, "getaddrinfo");
+    real_getaddrinfo = (getaddrinfo_call) dlsym(RTLD_NEXT, "getaddrinfo");
 
   if (!real_getaddrinfo) {
     errno = ENOTSUP;
