@@ -19,7 +19,7 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 /*
-  $Id: ruli_res.h,v 1.24 2004/06/21 00:22:39 evertonm Exp $
+  $Id: ruli_res.h,v 1.25 2004/10/05 23:04:28 evertonm Exp $
   */
 
 
@@ -123,7 +123,8 @@ enum {
   RULI_RES_OPT_SRV_NOINET6  = 1 << 3, /* Don't search IPv6 addresses */
   RULI_RES_OPT_SRV_URI_PORT = 1 << 4, /* Assume port was forced in URI */
   RULI_RES_OPT_SRV_NOWALK   = 1 << 5, /* Don't search missing addresses */
-  RULI_RES_OPT_SRV_NOFALL   = 1 << 6  /* Don't launch fallback queries */
+  RULI_RES_OPT_SRV_NOFALL   = 1 << 6, /* Don't launch fallback queries */
+  RULI_RES_OPT_SRV_NOSORT6  = 1 << 7  /* Don't sort favorably to v6 addrs */
 };
 
 typedef struct {
