@@ -19,7 +19,7 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 /*
-  $Id: ruli_smtp.c,v 1.17 2004/06/25 23:19:11 evertonm Exp $
+  $Id: ruli_smtp.c,v 1.19 2004/10/07 19:25:08 evertonm Exp $
   */
 
 
@@ -27,6 +27,7 @@ Boston, MA 02111-1307, USA.
 
 #include <assert.h>
 #include <string.h>
+#include <stdlib.h>
 
 #include <ruli_smtp.h>
 #include <ruli_mem.h>
@@ -34,8 +35,41 @@ Boston, MA 02111-1307, USA.
 #include <ruli_host.h>
 
 
-static void _m_query_done(ruli_srv_t *srv_qry, ruli_res_query_t *mx_qry) {
+static int srv_cmp_priority(const void *srv1, const void *srv2)
+{
+  /*
+  const ruli_srv_entry_t * const *s1 = (const ruli_srv_entry_t * const *) srv1;
+  const ruli_srv_entry_t * const *s2 = (const ruli_srv_entry_t * const *) srv2;
+
+  const ruli_srv_entry_t *e1 = (const ruli_srv_entry_t *) *s1;
+  const ruli_srv_entry_t *e2 = (const ruli_srv_entry_t *) *s2;
+  */
+
+  const ruli_srv_entry_t *e1 = *(const ruli_srv_entry_t * const *) srv1;
+  const ruli_srv_entry_t *e2 = *(const ruli_srv_entry_t * const *) srv2;
+
+  if (e1->priority < e2->priority)
+    return -1;
+  if (e1->priority > e2->priority)
+    return 1;
+
+  return 0;
+}
+
+static void sort_srv_by_mx_priority(ruli_srv_t *srv_qry)
+{
+  ruli_list_t *srv_list = &srv_qry->answer_srv_list;
+  void **srv_head = srv_list->head;
+  qsort(srv_head, ruli_list_size(srv_list), sizeof(void*), srv_cmp_priority);
+}
+
+static void _m_query_done(ruli_srv_t *srv_qry, ruli_res_query_t *mx_qry)
+{
   assert(mx_qry);
+
+  /* sort srv records by mx priority ? */
+  if (mx_qry->answer_code == RULI_CODE_OK)
+    sort_srv_by_mx_priority(srv_qry);
   
   ruli_res_query_delete(mx_qry);
   ruli_free(mx_qry);
@@ -85,7 +119,7 @@ static void *on_mx_answer(ruli_res_query_t *mx_qry, void *qry_arg)
   }
 #endif
 
-  assert(mx_qry->answer_code != RULI_SRV_CODE_VOID);
+  assert(mx_qry->answer_code != RULI_CODE_VOID);
   assert(!prev_srv_list_size);
 
   /*
@@ -329,7 +363,8 @@ static void *on_mx_answer(ruli_res_query_t *mx_qry, void *qry_arg)
 	      "DEBUG: %s: %s(): id=%d answer_code=%d, rcode=%d: "
 	      "BUT: no matching IN MX record\n",
 	      __FILE__, __PRETTY_FUNCTION__,
-	      qry->query_id, qry->answer_code, qry->answer_header.rcode);
+	      mx_qry->query_id, mx_qry->answer_code, 
+	      mx_qry->answer_header.rcode);
 #endif
 
     } /* MX scanning loop */    
