@@ -19,7 +19,7 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 /*
-  $Id: ruli_sock.h,v 1.8 2004/05/31 05:57:41 evertonm Exp $
+  $Id: ruli_sock.h,v 1.9 2004/09/11 00:39:03 evertonm Exp $
   */
 
 
@@ -48,8 +48,6 @@ int ruli_sock_create(int domain, int type, const char *proto_name);
 int ruli_sock_create_udp(int family);
 int ruli_sock_create_tcp(int family);
 int ruli_sock_has_connected(int tcp_sd);
-void ruli_sock_set_address(struct sockaddr *sa, int *sa_len, 
-			   const ruli_addr_t *addr, int port);
 int ruli_sock_connect(int sd, const ruli_addr_t *remote_addr, int rem_port);
 int ruli_sock_sendto(int sd, const ruli_addr_t *rem_addr, int rem_port,
 		     const ruli_uint8_t *buf, int msg_len);
