@@ -19,7 +19,7 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 /*
-  $Id: ruli_srv.c,v 1.75 2004/08/25 19:04:23 evertonm Exp $
+  $Id: ruli_srv.c,v 1.78 2004/10/08 04:22:15 evertonm Exp $
   */
 
 
@@ -44,6 +44,37 @@ const char *ruli_srv_errstr(int result)
   return "FIXME: ruli_srv_errstr()";
 }
 
+static void sort_by_addr_family(ruli_list_t *srv_list)
+{
+  int i;
+  int srv_list_size = ruli_list_size(srv_list);
+
+  /* scan srv entries */
+  for (i = 0; i < srv_list_size; ++i) {
+    ruli_srv_entry_t *entry = (ruli_srv_entry_t *) ruli_list_get(srv_list, i);
+    ruli_list_t *addr_list = &entry->addr_list;
+    int j = 0;
+    int k = ruli_list_size(addr_list) - 1;
+
+    /* sort addresses by family */
+    while (j < k) {
+      while ((j < k) && ruli_addr_family((ruli_addr_t *) ruli_list_get(addr_list, j)) == PF_INET6)
+	++j;
+      while ((j < k) && ruli_addr_family((ruli_addr_t *) ruli_list_get(addr_list, k)) == PF_INET)
+	--k;
+
+      /* swap? */
+      if (j < k) {
+	void *tmp = ruli_list_get(addr_list, j);
+	ruli_list_set(addr_list, j, ruli_list_get(addr_list, k));
+	ruli_list_set(addr_list, k, tmp);
+	++j;
+	--k;
+      }
+    }
+  }
+}
+
 /*
   This is an indirection to the srv user callback
   */
@@ -54,6 +85,11 @@ void *_ruli_srv_query_done(ruli_srv_t *srv_qry, int srv_result_code)
 
   srv_qry->answer_code = srv_result_code;
 
+  /* Move IPv6 addresses to begin ? */
+  if (srv_result_code == RULI_SRV_CODE_OK)
+    if (!(srv_qry->srv_options & RULI_RES_OPT_SRV_NOSORT6))
+      sort_by_addr_family(&srv_qry->answer_srv_list);
+
   /*
    * Invoke srv user callback
    */
@@ -77,13 +113,14 @@ static void f_query_done(ruli_host_t *fall_qry) {
 /*
   finish fallback query
  */
-static void *fall_query_done(ruli_srv_t *srv_qry, int srv_result_code, ruli_host_t *fall_qry)
+static void *fall_query_done(ruli_srv_t *srv_qry, int srv_result_code, 
+			     ruli_host_t *fall_qry)
 {
 #ifdef RULI_SRV_DEBUG
   fprintf(stderr, 
 	  "DEBUG: %s: %s(): %d: id=%d query_result=%s [%d]\n", 
 	  __FILE__, __PRETTY_FUNCTION__, __LINE__,
-	  srv_qry->fall_query->query_id,
+	  fall_qry->host_query.query_id,
 	  srv_result_code ? "FAIL" : "SUCCESS", 
 	  srv_result_code);
 #endif
@@ -120,7 +157,7 @@ static void *walk_query_done(walk_t *walk, int srv_result_code)
   fprintf(stderr, 
 	  "DEBUG: %s: %s(): %d: id=%d query_result=%s [%d]\n", 
 	  __FILE__, __PRETTY_FUNCTION__, __LINE__,
-	  srv_qry->walk_query->query_id,
+	  walk->walk_query.host_query.query_id,
 	  srv_result_code ? "FAIL" : "SUCCESS", 
 	  srv_result_code);
 #endif
@@ -151,8 +188,8 @@ static void *on_walk_answer(ruli_host_t *host_qry, void *qry_arg)
     
     result = ruli_dname_decode(target_txt, RULI_LIMIT_DNAME_TEXT_BUFSZ, 
 			       &target_txt_len, 
-			       (const char *) qry->full_dname, 
-			       qry->full_dname_len);
+			       (const char *) walk_qry->walk_query.host_query.full_dname, 
+			       walk_qry->walk_query.host_query.full_dname_len);
     assert(!result);
     
     fprintf(stderr, 
@@ -174,6 +211,11 @@ static void *on_walk_answer(ruli_host_t *host_qry, void *qry_arg)
         return walk_query_done(walk_qry, RULI_SRV_CODE_WALK_ALARM);
       case RULI_HOST_CODE_EMPTY:
         return walk_query_done(walk_qry, RULI_SRV_CODE_WALK_EMPTY);
+      case RULI_HOST_CODE_RCODE:
+	assert(ruli_host_rcode(host_qry) != RULI_RCODE_VOID);
+	assert(ruli_host_rcode(host_qry) != RULI_RCODE_NOERROR);
+	srv_qry->last_rcode = ruli_host_rcode(host_qry);
+	return walk_query_done(walk_qry, RULI_SRV_CODE_WALK_RCODE);
       default:
         return walk_query_done(walk_qry, RULI_SRV_CODE_WALK_QUERY);
       }
@@ -182,15 +224,8 @@ static void *on_walk_answer(ruli_host_t *host_qry, void *qry_arg)
     }
   }
 
-  /*
-   * Bad RCODE ?
-   */
-  {
-    ruli_uint16_t rcode = ruli_host_rcode(host_qry);
-    srv_qry->last_rcode = rcode;
-    if (rcode != RULI_RCODE_NOERROR)
-      return walk_query_done(walk_qry, RULI_SRV_CODE_FALL_RCODE);
-  }
+  assert(ruli_host_rcode(host_qry) == RULI_RCODE_NOERROR);
+  srv_qry->last_rcode = RULI_RCODE_NOERROR;
 
   /*
    * Move addresses into SRV record
@@ -266,9 +301,11 @@ void *_ruli_srv_answer_walk(ruli_srv_t *srv_qry)
   /*
    * Scan SRV answer targets, considering address lists
    */
-  for (; srv_qry->under.walk_index < srv_list_size; ++srv_qry->under.walk_index) {
-    ruli_srv_entry_t *entry = (ruli_srv_entry_t *) ruli_list_get(srv_list, 
-						   srv_qry->under.walk_index);
+  for (; srv_qry->under.walk_index < srv_list_size; 
+       ++srv_qry->under.walk_index) {
+    ruli_srv_entry_t *entry = \
+      (ruli_srv_entry_t *) ruli_list_get(srv_list, 
+					 srv_qry->under.walk_index);
     ruli_list_t *addr_list = &entry->addr_list;
     walk_t *walk_qry;
 
@@ -289,8 +326,8 @@ void *_ruli_srv_answer_walk(ruli_srv_t *srv_qry)
       
       fprintf(stderr, 
 	      "DEBUG: _ruli_srv_answer_walk(): "
-              "missing target=%s walk_index=%d walk_qtype=%d\n", 
-	      target_txt, srv_qry->walk_index, srv_qry->walk_qtype);
+              "missing target=%s walk_index=%d\n", 
+	      target_txt, srv_qry->under.walk_index);
     }
 #endif
     
@@ -357,6 +394,11 @@ static void *on_fallback_answer(ruli_host_t *qry, void *qry_arg)
       return fall_query_done(srv_qry, RULI_SRV_CODE_FALL_ALARM, qry);
     case RULI_HOST_CODE_EMPTY:
       return fall_query_done(srv_qry, RULI_SRV_CODE_FALL_EMPTY, qry);
+    case RULI_HOST_CODE_RCODE:
+      assert(ruli_host_rcode(qry) != RULI_RCODE_VOID);
+      assert(ruli_host_rcode(qry) != RULI_RCODE_NOERROR);
+      srv_qry->last_rcode = ruli_host_rcode(qry);
+      return fall_query_done(srv_qry, RULI_SRV_CODE_FALL_RCODE, qry);
     default: 
       return fall_query_done(srv_qry, RULI_SRV_CODE_FALL_QUERY, qry);
     }
@@ -364,15 +406,8 @@ static void *on_fallback_answer(ruli_host_t *qry, void *qry_arg)
     assert(0);
   }
 
-  /*
-   * Bad RCODE ?
-   */
-  {
-    ruli_uint16_t rcode = ruli_host_rcode(qry);
-    srv_qry->last_rcode = rcode;
-    if (rcode != RULI_RCODE_NOERROR)
-      return fall_query_done(srv_qry, RULI_SRV_CODE_FALL_RCODE, qry);
-  }
+  assert(ruli_host_rcode(qry) == RULI_RCODE_NOERROR);
+  srv_qry->last_rcode = RULI_RCODE_NOERROR;
 
   /*
    * Move addresses into SRV record
@@ -1180,12 +1215,9 @@ void ruli_srv_query_delete(ruli_srv_t *srv_qry)
 {
 #ifdef RULI_SRV_DEBUG
   fprintf(stderr, 
-	  "DEBUG: %s: %s(): %d: "
-	  "query_id=%d fall_query_id=%d walk_query_id=%d\n", 
+	  "DEBUG: %s: %s(): %d: query_id=%d\n", 
 	  __FILE__, __PRETTY_FUNCTION__, __LINE__,
-	  srv_qry->query.query_id,
-	  srv_qry->fall_query ? srv_qry->fall_query->query_id : -1,
-	  srv_qry->walk_query ? srv_qry->walk_query->query_id : -1);
+	  srv_qry->query.query_id);
 #endif /* RULI_SRV_DEBUG */
 
   /*
