@@ -19,7 +19,7 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 /*
-  $Id: cycle_res2.c,v 1.4 2004/05/24 02:43:21 evertonm Exp $
+  $Id: cycle_res2.c,v 1.5 2004/06/01 18:37:34 evertonm Exp $
  */
 
 
@@ -60,10 +60,8 @@ static void go()
   int		      i;
   ruli_conf_handler_t handler;
 
-  result = inet_aton("127.0.0.1", &server_addr.addr.ipv4);
+  result = ruli_addr_parse("127.0.0.1", &server_addr);
   assert(result);
-  server_addr.addr_family = PF_INET;
-  server_addr.addr_size = sizeof(server_addr.addr.ipv4);
 
   source_sys = oop_sys_new();
   assert(source_sys);
