@@ -19,7 +19,7 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 /*
-  $Id: hostsolver.c,v 1.18 2004/06/16 17:28:44 evertonm Exp $
+  $Id: hostsolver.c,v 1.19 2004/06/23 19:47:29 evertonm Exp $
  */
 
 
@@ -126,7 +126,7 @@ static void *on_answer(ruli_res_query_t *qry, void *arg)
   char       buf[BUFSZ];
   int        str_len;
 
-  assert(qry->answer_code != RULI_SRV_CODE_VOID);
+  assert(qry->answer_code != RULI_CODE_VOID);
 
   if (qry->answer_code == RULI_CODE_TIMEOUT) {
     str_len = snprintf(buf, BUFSZ, "%s query-timeout\n", domain);
